@@ -17,10 +17,24 @@ import cairo
 import pytest
 
 
+def test_get_include():
+    include = cairo.get_include()
+    assert isinstance(include, str)
+    assert os.path.exists(include)
+    assert os.path.isdir(include)
+
+
 def test_version():
     cairo.cairo_version()
     cairo.cairo_version_string()
 
+    assert cairo.CAIRO_VERSION == cairo.cairo_version()
+    assert cairo.CAIRO_VERSION_STRING == cairo.cairo_version_string()
+    ver_tuple = (cairo.CAIRO_VERSION_MAJOR, cairo.CAIRO_VERSION_MINOR,
+                 cairo.CAIRO_VERSION_MICRO)
+    assert tuple(map(int, cairo.CAIRO_VERSION_STRING.split("."))) == \
+        ver_tuple
+
 
 def test_show_unicode_text():
     width, height = 300, 300
